@@ -22,6 +22,9 @@
 
 configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
 {
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+
     settings = mainSettings;
     parent   = mainParent;
 
@@ -30,8 +33,7 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     QGridLayout *layout = new QGridLayout();
 
     //Ok Button
-    QPushButton *okButton = new QPushButton(tr("Save"));
-    okButton->setFixedWidth(210);
+    okButton = new QPushButton(tr("Save"));
     connect(okButton, SIGNAL(clicked(bool)), this, SLOT(okButtonClicked()));
 
     //Store last search
@@ -108,6 +110,20 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     layout->addWidget(backendButton, 4, 0);
     layout->addWidget(okButton, 4, 1);
     setLayout(layout);
+
+    orientationChanged();
+}
+
+void configDialog::orientationChanged()
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    QGridLayout *layout = (QGridLayout*)this->layout();
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        layout->addWidget(okButton, 4, 1);
+    } else {
+        layout->addWidget(okButton, 5, 0);
+    }
 }
 
 void configDialog::storelastSearchToggled(int state)
