@@ -4,52 +4,55 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.cpp" line="31"/>
+        <location filename="mainwindow.cpp" line="30"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="36"/>
+        <location filename="mainwindow.cpp" line="35"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="41"/>
-        <source>Toggle GPS</source>
-        <translation>GPS An/Aus</translation>
+        <location filename="mainwindow.cpp" line="40"/>
+        <location filename="mainwindow.cpp" line="126"/>
+        <location filename="mainwindow.cpp" line="270"/>
+        <source>Enable GPS</source>
+        <oldsource>Toggle GPS</oldsource>
+        <translation>GPS einschalten</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="46"/>
-        <location filename="mainwindow.cpp" line="322"/>
+        <location filename="mainwindow.cpp" line="45"/>
+        <location filename="mainwindow.cpp" line="326"/>
         <source>Donate</source>
         <translation>Spenden</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="62"/>
+        <location filename="mainwindow.cpp" line="61"/>
         <source>Station from</source>
         <translation>Haltestelle ab</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="63"/>
+        <location filename="mainwindow.cpp" line="62"/>
         <source>Station to</source>
         <translation>Haltestelle bis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="66"/>
-        <location filename="mainwindow.cpp" line="68"/>
-        <location filename="mainwindow.cpp" line="226"/>
-        <location filename="mainwindow.cpp" line="227"/>
-        <location filename="mainwindow.cpp" line="699"/>
+        <location filename="mainwindow.cpp" line="61"/>
+        <location filename="mainwindow.cpp" line="62"/>
+        <location filename="mainwindow.cpp" line="231"/>
+        <location filename="mainwindow.cpp" line="232"/>
+        <location filename="mainwindow.cpp" line="702"/>
         <source>please select</source>
         <translation>bitte wählen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="92"/>
+        <location filename="mainwindow.cpp" line="80"/>
         <source>Date</source>
         <translation>Datum</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="96"/>
+        <location filename="mainwindow.cpp" line="84"/>
         <source>Time</source>
         <translation>Uhrzeit</translation>
     </message>
@@ -58,33 +61,39 @@
         <translation type="obsolete">- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="295"/>
+        <location filename="mainwindow.cpp" line="299"/>
         <source>Arrival time</source>
         <translation>Ankunft</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="112"/>
-        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="89"/>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>Departure time</source>
         <translation>Abfahrt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="110"/>
+        <location filename="mainwindow.cpp" line="89"/>
         <source>Use selected date/time as</source>
         <translation>Datum und Zeit verwenden als</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="119"/>
+        <location filename="mainwindow.cpp" line="96"/>
         <source>Restrict train types</source>
         <translation>Verkehrsmittel</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="130"/>
+        <location filename="mainwindow.cpp" line="100"/>
         <source>Search</source>
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="189"/>
+        <location filename="mainwindow.cpp" line="122"/>
+        <location filename="mainwindow.cpp" line="276"/>
+        <source>Disable GPS</source>
+        <translation>GPS ausschalten</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="153"/>
         <source>Welcome to a new version of fahrplan this has changed</source>
         <translation>Willkommen bei einer neuen Version von Fahrplan, dies ist neu</translation>
     </message>
@@ -97,22 +106,22 @@
         <translation type="obsolete">-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="233"/>
+        <location filename="mainwindow.cpp" line="237"/>
         <source>not supported</source>
         <translation>nicht unterstützt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="257"/>
+        <location filename="mainwindow.cpp" line="259"/>
         <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="268"/>
+        <location filename="mainwindow.cpp" line="271"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="273"/>
+        <location filename="mainwindow.cpp" line="277"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
     </message>
@@ -121,7 +130,7 @@
         <translation type="obsolete">Verbindung: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="464"/>
+        <location filename="mainwindow.cpp" line="468"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
@@ -159,12 +168,12 @@
         <translation type="obsolete">- sbb.ch: fehler im parser behoben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="323"/>
+        <location filename="mainwindow.cpp" line="327"/>
         <source>Thank you for Donating!</source>
         <translation>Danke fürs spenden!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="329"/>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
         <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
     </message>
@@ -173,87 +182,93 @@
         <translation type="obsolete">&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="190"/>
         <source>- adding 131500.com.au backend</source>
-        <translation>- 131500.com.au backend hinzugefügt</translation>
+        <translation type="obsolete">- 131500.com.au backend hinzugefügt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="329"/>
+        <location filename="mainwindow.cpp" line="154"/>
+        <source>- bugfixes for 131500.com.au backend
+- support for portrait mode</source>
+        <translation>- fehlerbehebungen für  131500.com.au backend
+- unterstützung für portrait modus</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
         <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="331"/>
+        <location filename="mainwindow.cpp" line="335"/>
         <source>About Fahrplan</source>
         <translation>Über Fahrplan</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="358"/>
+        <location filename="mainwindow.cpp" line="362"/>
         <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
         <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="372"/>
+        <location filename="mainwindow.cpp" line="376"/>
         <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
         <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="378"/>
+        <location filename="mainwindow.cpp" line="382"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="387"/>
+        <location filename="mainwindow.cpp" line="391"/>
         <source>Add to calendar</source>
         <translation>In Kalender eintragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="469"/>
+        <location filename="mainwindow.cpp" line="473"/>
         <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
         <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="504"/>
+        <location filename="mainwindow.cpp" line="508"/>
         <source>&lt;br&gt;No results found.&lt;br&gt;</source>
         <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="523"/>
+        <location filename="mainwindow.cpp" line="527"/>
         <source>Results</source>
         <translation>Ergebnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="540"/>
+        <location filename="mainwindow.cpp" line="544"/>
         <source>to</source>
         <translation>nach</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="551"/>
+        <location filename="mainwindow.cpp" line="555"/>
         <source>Earlier</source>
         <translation>Früher</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="557"/>
+        <location filename="mainwindow.cpp" line="561"/>
         <source>Later</source>
         <translation>Später</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="570"/>
+        <location filename="mainwindow.cpp" line="574"/>
         <source> transfer</source>
         <translation> umstieg</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="573"/>
+        <location filename="mainwindow.cpp" line="577"/>
         <source> transfers</source>
         <translation> umstiege</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="592"/>
+        <location filename="mainwindow.cpp" line="596"/>
         <source>&lt;br&gt;OnTime</source>
         <translation>&lt;br&gt;Pünktlich</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="729"/>
+        <location filename="mainwindow.cpp" line="732"/>
         <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
         <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
     </message>
@@ -261,33 +276,33 @@
 <context>
     <name>calendarDialog</name>
     <message>
-        <location filename="calendardialog.cpp" line="29"/>
+        <location filename="calendardialog.cpp" line="31"/>
         <source>Select target calendar</source>
         <translation>Ziel Kalender wählen</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="157"/>
+        <location filename="calendardialog.cpp" line="159"/>
         <source>Private</source>
         <translation>Privat</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="173"/>
+        <location filename="calendardialog.cpp" line="175"/>
         <source>Journey: </source>
         <translation>Verbindung: </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="173"/>
-        <location filename="calendardialog.cpp" line="174"/>
+        <location filename="calendardialog.cpp" line="175"/>
+        <location filename="calendardialog.cpp" line="176"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="182"/>
+        <location filename="calendardialog.cpp" line="184"/>
         <source>Duration: </source>
         <translation>Dauer: </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="219"/>
+        <location filename="calendardialog.cpp" line="221"/>
         <source>
 
 (added by fahrplan app, please recheck informations before travel.)</source>
@@ -296,28 +311,28 @@
 (hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="250"/>
+        <location filename="calendardialog.cpp" line="252"/>
         <source>&lt;br&gt;Entry already exists!&lt;br&gt;</source>
         <translation>&lt;br&gt;Eintrag existiert bereits!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="252"/>
+        <location filename="calendardialog.cpp" line="254"/>
         <source>&lt;br&gt;An error occured while adding the entry!&lt;br&gt;</source>
         <translation>&lt;br&gt;Beim hinzufügen ist ein Fehler aufgetreten!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="98"/>
-        <location filename="calendardialog.cpp" line="229"/>
+        <location filename="calendardialog.cpp" line="100"/>
+        <location filename="calendardialog.cpp" line="231"/>
         <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
         <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="248"/>
+        <location filename="calendardialog.cpp" line="250"/>
         <source>&lt;br&gt;Entry added to the </source>
         <translation>&lt;br&gt;Eintrag wurde zum </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="248"/>
+        <location filename="calendardialog.cpp" line="250"/>
         <source> calendar.&lt;br&gt;</source>
         <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
     </message>
@@ -325,57 +340,57 @@
 <context>
     <name>configDialog</name>
     <message>
-        <location filename="configdialog.cpp" line="28"/>
+        <location filename="configdialog.cpp" line="31"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="33"/>
+        <location filename="configdialog.cpp" line="36"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="39"/>
+        <location filename="configdialog.cpp" line="41"/>
         <source>Store last searched stations</source>
         <translation>zuletzt verwendete Haltestellen speichern</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="45"/>
+        <location filename="configdialog.cpp" line="47"/>
         <source>Prefill last searched station</source>
         <translation>letzte Haltestellen automatisch füllen</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="51"/>
+        <location filename="configdialog.cpp" line="53"/>
         <source>Launch GPS on startup</source>
         <translation>GPS automatisch starten</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="56"/>
+        <location filename="configdialog.cpp" line="58"/>
         <source>Use OpenStreetMap as fallback for GPS</source>
         <translation>OpenStreetMap als Sicherheit nutzen (GPS)</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="61"/>
+        <location filename="configdialog.cpp" line="63"/>
         <source>bahn.de</source>
         <translation>bahn.de</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="65"/>
+        <location filename="configdialog.cpp" line="67"/>
         <source>mvv-muenchen.de</source>
         <translation>mvv-muenchen.de</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="69"/>
+        <location filename="configdialog.cpp" line="71"/>
         <source>sbb.ch</source>
         <translation>sbb.ch</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="73"/>
+        <location filename="configdialog.cpp" line="75"/>
         <source>131500.com.au</source>
         <translation>131500.com.au</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="77"/>
+        <location filename="configdialog.cpp" line="79"/>
         <source>Databackend</source>
         <translation>Datenquelle</translation>
     </message>
@@ -452,22 +467,22 @@
 <context>
     <name>selectStationDialog</name>
     <message>
-        <location filename="selectstationdialog.cpp" line="25"/>
+        <location filename="selectstationdialog.cpp" line="28"/>
         <source>City Stationname</source>
         <translation>Stadt Haltestellenname</translation>
     </message>
     <message>
-        <location filename="selectstationdialog.cpp" line="50"/>
+        <location filename="selectstationdialog.cpp" line="53"/>
         <source>GPS</source>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="selectstationdialog.cpp" line="51"/>
+        <location filename="selectstationdialog.cpp" line="54"/>
         <source>Search</source>
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="selectstationdialog.cpp" line="122"/>
+        <location filename="selectstationdialog.cpp" line="135"/>
         <source>Select a station</source>
         <translation>Haltestelle wählen</translation>
     </message>
