@@ -23,9 +23,8 @@
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), resultWindow(0), detailsWindow(0)
 {
-    QWidget *mainWidget = new QWidget;
-    QGtkStyle *gtkStyle = new QGtkStyle();
-    setCentralWidget(mainWidget);
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 
     //About Menu Button
     QAction *aboutAct = new QAction(tr("About"), this);
@@ -38,7 +37,7 @@ MainWindow::MainWindow(QWidget *parent)
     menuBar()->addAction(settingsAct);
 
     //Toggle GPS Button
-    QAction *gpsAct = new QAction(tr("Toggle GPS"), this);
+    gpsAct = new QAction(tr("Enable GPS"), this);
     connect(gpsAct, SIGNAL(triggered()), this, SLOT(gpsButtonClicked()));
     menuBar()->addAction(gpsAct);
 
@@ -49,46 +48,35 @@ MainWindow::MainWindow(QWidget *parent)
 
     setWindowTitle("Fahrplan");
 
-    //Main Window Layout
-    QVBoxLayout *layout = new QVBoxLayout;
+    QWidget *mainWidget = new QWidget;
+    setCentralWidget(mainWidget);
+
+    QGridLayout *layout = new QGridLayout();
+    mainWidget->setLayout(layout);
 
     //From and To and Swap Buttons
-    QHBoxLayout *stationsHLayout = new QHBoxLayout;
-    QVBoxLayout *stationsVLayout = new QVBoxLayout;
+    QGridLayout *stationsLayout = new QGridLayout();
+    QWidget *stationsContainerWidget = new QWidget;
 
-    QWidget *stationsVContainer  = new QWidget;
-    QWidget *stationsHContainer  = new QWidget;
+    stationDeparture = new QValueButton(tr("Station from"), tr("please select"));
+    stationArrival   = new QValueButton(tr("Station to"), tr("please select"));
 
-    stationDeparture             = new QMaemo5ValueButton(tr("Station from"));
-    stationArrival               = new QMaemo5ValueButton(tr("Station to"));
-    QPushButton *stationSwap     = new QPushButton("");
-
-    stationDeparture->setValueText(tr("please select"));
-    stationDeparture->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-    stationArrival->setValueText(tr("please select"));
-    stationArrival->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-    stationSwap->setFixedWidth(50);
-    stationSwap->setFixedHeight(150);
-    stationSwap->setStyle(gtkStyle);
+    stationSwap      = new QPushButton(QChar(8597));
 
     connect(stationDeparture, SIGNAL(clicked(bool)), this, SLOT(stationDepartureClicked()));
     connect(stationArrival, SIGNAL(clicked(bool)), this, SLOT(stationArrivalClicked()));
     connect(stationSwap, SIGNAL(clicked(bool)), this, SLOT(swapClicked()));
 
-    stationsVLayout->setMargin(1);
-    stationsVLayout->addWidget(stationDeparture);
-    stationsVLayout->addWidget(stationArrival);
-    stationsVContainer->setLayout(stationsVLayout);
+    stationsLayout->setMargin(0);
+    stationsLayout->setSpacing(10);
+    stationsLayout->addWidget(stationDeparture, 0, 0);
+    stationsLayout->addWidget(stationArrival, 1, 0);
+    stationsLayout->addWidget(stationSwap, 0, 1, 0, 1);
+    stationsContainerWidget->setLayout(stationsLayout);
 
-    stationsHLayout->setMargin(0);
-    stationsHLayout->addWidget(stationsVContainer);
-    stationsHLayout->addWidget(stationSwap);
-    stationsHContainer->setLayout(stationsHLayout);
+    layout->addWidget(stationsContainerWidget, 0, 0, 1, 0);
 
     //Date and Time Buttons
-    QHBoxLayout *datetimeHLayout = new QHBoxLayout;
-    QWidget     *datetimeHContainer = new QWidget;
-
     dateSelector  = new QMaemo5ValueButton(tr("Date"));
     dateSelector->setPickSelector(new QMaemo5DatePickSelector());
     dateSelector->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
@@ -97,50 +85,23 @@ MainWindow::MainWindow(QWidget *parent)
     timeSelector->setPickSelector(new QMaemo5TimePickSelector());
     timeSelector->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
 
-    datetimeHLayout->setMargin(0);
-    datetimeHLayout->setSpacing(0);
-    datetimeHLayout->addWidget(dateSelector);
-    datetimeHLayout->addWidget(timeSelector);
-    datetimeHContainer->setLayout(datetimeHLayout);
-
-    QHBoxLayout *optionsHLayout = new QHBoxLayout;
-    QWidget     *optionsHContainer = new QWidget;
-
     //Departure/Arrival Selector Button
-    modeButton = new QMaemo5ValueButton(tr("Use selected date/time as"));
-    modeButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-    modeButton->setValueText(tr("Departure time"));
+    modeButton = new QValueButton(tr("Use selected date/time as"), tr("Departure time"));
     ModeButtonUserData *mode = new ModeButtonUserData();
     mode->mode = 1;
     modeButton->setUserData(0, mode);
     connect(modeButton, SIGNAL(clicked(bool)), this, SLOT(modeClicked()));
 
     //Restrict Train Types
-    traintypesButton = new QMaemo5ValueButton(tr("Restrict train types"));
-    traintypesButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-
-    optionsHLayout->setMargin(0);
-    optionsHLayout->setSpacing(0);
-    optionsHLayout->addWidget(modeButton);
-    optionsHLayout->addWidget(traintypesButton);
-    optionsHContainer->setLayout(optionsHLayout);
+    traintypesButton = new QValueButton(tr("Restrict train types"), "");
 
     //Search Button
     searchButton = new QPushButton();
     searchButton->setText(tr("Search"));
-    searchButton->setFixedHeight(100);
-    searchButton->setStyle(gtkStyle);
+
     connect(searchButton, SIGNAL(clicked(bool)), this, SLOT(searchButtonClicked(bool)));
 
     //Add all to Layout
-    layout->setMargin(1);
-    layout->setStretch(0, 2);
-    layout->addWidget(stationsHContainer);
-    layout->addWidget(datetimeHContainer);
-    layout->addWidget(optionsHContainer);
-    layout->addWidget(searchButton);
-    mainWidget->setLayout(layout);
-
     #ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5StackedWindow);
     #endif
@@ -158,9 +119,11 @@ MainWindow::MainWindow(QWidget *parent)
     {
         locationDataSource->startUpdates();
         locationDataSourceIsUpdating = true;
+        gpsAct->setText(tr("Disable GPS"));
     } else
     {
         locationDataSourceIsUpdating = false;
+        gpsAct->setText(tr("Enable GPS"));
     }
 
     //Prefill stations
@@ -175,25 +138,67 @@ MainWindow::MainWindow(QWidget *parent)
 
         if (stationsList.count() > 1)
         {
-            stationDeparture->setValueText(stationsList[1]);
-            stationArrival->setValueText(stationsList[0]);
+            stationDeparture->setDescription(stationsList[1]);
+            stationArrival->setDescription(stationsList[0]);
         }
     }
 
     initBackend();
+    orientationChanged();
 
     //Show first launch msg
     if (settings->value("firstLaunch", "") != APP_VER)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this has changed"),
-                           tr("- adding 131500.com.au backend")
+                           tr("- bugfixes for 131500.com.au backend\n- support for portrait mode")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
     }
 }
 
+void MainWindow::orientationChanged()
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    QGridLayout *layout = (QGridLayout*)this->centralWidget()->layout();
+
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        layout->addWidget(dateSelector, 1, 0);
+        layout->addWidget(timeSelector, 1, 1);
+        layout->addWidget(modeButton, 2, 0);
+        layout->addWidget(traintypesButton, 2, 1);
+        layout->addWidget(searchButton, 3, 0, 1, 0);
+
+        dateSelector->setFixedHeight(78);
+        timeSelector->setFixedHeight(78);
+        modeButton->setFixedHeight(78);
+        traintypesButton->setFixedHeight(78);
+        stationDeparture->setFixedHeight(78);
+        stationArrival->setFixedHeight(78);
+        stationSwap->setFixedHeight(160);
+        stationSwap->setFixedWidth(50);
+        searchButton->setFixedHeight(78);
+    } else {
+        layout->addWidget(dateSelector, 1, 0, 1, 0);
+        layout->addWidget(timeSelector, 2, 0, 1, 0);
+        layout->addWidget(modeButton, 3, 0, 1, 0);
+        layout->addWidget(traintypesButton, 4, 0, 1, 0);
+        layout->addWidget(searchButton, 5, 0, 1, 0);
+
+        dateSelector->setFixedHeight(98);
+        timeSelector->setFixedHeight(98);
+        modeButton->setFixedHeight(98);
+        traintypesButton->setFixedHeight(98);
+        stationDeparture->setFixedHeight(98);
+        stationArrival->setFixedHeight(98);
+        stationSwap->setFixedHeight(200);
+        stationSwap->setFixedWidth(50);
+        searchButton->setFixedHeight(98);
+    }
+}
+
 void MainWindow::initBackend(bool resetStations)
 {
     QString backendType = settings->value("backend", "parserMobileBahnDe").toString();
@@ -223,14 +228,13 @@ void MainWindow::initBackend(bool resetStations)
     }
 
     if (resetStations) {
-        stationArrival->setValueText(tr("please select"));
-        stationDeparture->setValueText(tr("please select"));
+        stationArrival->setDescription(tr("please select"));
+        stationDeparture->setDescription(tr("please select"));
     }
 
     //Update gui based on Backend
     QStringList trainRestrictions = backendParser->getTrainRestrictions();
-    traintypesButton->setPickSelector(NULL);
-    traintypesButton->setValueText(tr("not supported"));
+    traintypesButton->setDescription(tr("not supported"));
     traintypesButton->setEnabled(false);
     if (trainRestrictions.count() > 0)
     {
@@ -242,10 +246,8 @@ void MainWindow::initBackend(bool resetStations)
             item->setEditable(false);
             trainrestrModel->appendRow(item);
         }
-        QMaemo5ListPickSelector *trainrestrSelector = new QMaemo5ListPickSelector;
-        trainrestrSelector->setModel(trainrestrModel);
-        trainrestrSelector->setCurrentIndex(0);
-        traintypesButton->setPickSelector(trainrestrSelector);
+        traintypesButton->setModel(trainrestrModel);
+        traintypesButton->setModelIndex(0);
         traintypesButton->setEnabled(true);
     }
 }
@@ -265,34 +267,36 @@ void MainWindow::gpsButtonClicked()
     {
         locationDataSource->stopUpdates();
         locationDataSourceIsUpdating = false;
+        gpsAct->setText(tr("Enable GPS"));
         QMaemo5InformationBox::information(this, tr("<br>GPS is now <b>disabled</b><br>"), QMaemo5InformationBox::DefaultTimeout);
     } else
     {
         locationDataSource->startUpdates();
         locationDataSourceIsUpdating = true;
+        gpsAct->setText(tr("Disable GPS"));
         QMaemo5InformationBox::information(this, tr("<br>GPS is now <b>enabled</b><br>"), QMaemo5InformationBox::DefaultTimeout);
     }
 }
 
 void MainWindow::swapClicked()
 {
-    QString tmp = stationDeparture->valueText();
-    stationDeparture->setValueText(stationArrival->valueText());
-    stationArrival->setValueText(tmp);
+    QString tmp = stationDeparture->description();
+    stationDeparture->setDescription(stationArrival->description());
+    stationArrival->setDescription(tmp);
 }
 
 void MainWindow::modeClicked()
 {
-    QMaemo5ValueButton *button = (QMaemo5ValueButton *)sender();
+    QValueButton *button = (QValueButton *)sender();
     ModeButtonUserData *mode = (ModeButtonUserData*)button->userData(0);
     if (mode->mode == 0)
     {
         mode->mode = 1;
-        modeButton->setValueText(tr("Departure time"));
+        modeButton->setDescription(tr("Departure time"));
 
     } else {
         mode->mode = 0;
-        modeButton->setValueText(tr("Arrival time"));
+        modeButton->setDescription(tr("Arrival time"));
     }
     button->setUserData(0,mode);
 }
@@ -692,19 +696,18 @@ void MainWindow::searchButtonClicked(bool checked)
         int trainrestrictions = 0;
         if (backendParser->getTrainRestrictions().count() > 0)
         {
-            QMaemo5ListPickSelector *trainSel = (QMaemo5ListPickSelector *)traintypesButton->pickSelector();
-            trainrestrictions = trainSel->currentIndex();
+            trainrestrictions = traintypesButton->modelIndex();
         }
 
-        if (stationDeparture->valueText() != stationArrival->valueText() && stationDeparture->valueText() != tr("please select") && stationArrival->valueText() != tr("please select"))
+        if (stationDeparture->description() != stationArrival->description() && stationDeparture->description() != tr("please select") && stationArrival->description() != tr("please select"))
         {
             //Store last search data
             if (settings->value("storelastsearch", true).toBool() ==  true)
             {
                 QStringList oldList;
                 oldList = settings->value("lastsearch/stations", oldList).toStringList();
-                oldList.append(stationDeparture->valueText().trimmed());
-                oldList.append(stationArrival->valueText().trimmed());
+                oldList.append(stationDeparture->description().trimmed());
+                oldList.append(stationArrival->description().trimmed());
 
                 //We need to reverse the order before removing duplicates
                 //to ensure the latest station is later on the bottom
@@ -722,7 +725,7 @@ void MainWindow::searchButtonClicked(bool checked)
             }
 
             searchButton->setEnabled(false);
-            lastSearchResult = backendParser->getJourneyData(stationDeparture->valueText(), stationArrival->valueText(), "", dateSel->currentDate(), timeSel->currentTime(), mode->mode, trainrestrictions);
+            lastSearchResult = backendParser->getJourneyData(stationDeparture->description(), stationArrival->description(), "", dateSel->currentDate(), timeSel->currentTime(), mode->mode, trainrestrictions);
             showResultWindow();
         } else
         {
