@@ -44,8 +44,9 @@
 #include "selectstationdialog.h"
 #include "configdialog.h"
 #include "calendardialog.h"
+#include "qvaluebutton.h"
 
-#define APP_VER "0.0.19"
+#define APP_VER "0.0.20"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -74,6 +75,7 @@ public:
 public slots:
     void positionUpdated(QGeoPositionInfo geoPositionInfo);
     Q_SCRIPTABLE int top_application();
+    void orientationChanged();
 
 private slots:
     void searchButtonClicked(bool checked = false);
@@ -92,13 +94,15 @@ private slots:
     void resultItemClicked();
 
 private:
+    QAction *gpsAct;
     QPushButton        *searchButton;
-    QMaemo5ValueButton *stationDeparture;
-    QMaemo5ValueButton *stationArrival;
+    QValueButton       *stationDeparture;
+    QValueButton       *stationArrival;
+    QPushButton *stationSwap;
     QMaemo5ValueButton *dateSelector;
     QMaemo5ValueButton *timeSelector;
-    QMaemo5ValueButton *modeButton;
-    QMaemo5ValueButton *traintypesButton;
+    QValueButton *modeButton;
+    QValueButton *traintypesButton;
     ResultInfo         lastSearchResult;
     DetailResultInfo   lastSearchDetails;
     QPointer<QMainWindow> resultWindow;
