@@ -130,8 +130,8 @@ ResultInfo parser131500ComAu::getJourneyData(QString destinationStation, QString
     fullUrl.append("&itd_itdTimeMinute=" + time.toString("mm"));
     fullUrl.append("&itd_itdTripDateTimeDepArr=" + modeString);
     fullUrl.append("&itd_itdTimeAMPM=" + hourStr);
-    fullUrl.append("&itd_name_origin=" + arrivalStation);
-    fullUrl.append("&itd_name_destination=" + destinationStation);
+    fullUrl.append("&itd_name_origin=" + destinationStation);
+    fullUrl.append("&itd_name_destination=" + arrivalStation);
 
     // itd_inclMOT_5 = bus
     // itd_inclMOT_1 = train
@@ -257,6 +257,7 @@ ResultInfo parser131500ComAu::getJourneyData(QString destinationStation, QString
     while ((pos = regexp.indexIn(filebuffer->buffer(), pos)) != -1) {
         QString element = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body><table>\n" + regexp.cap(1) + "\n</table></body>\n</html>\n";
         element.replace("&nbsp;", " ");
+        element.replace("bulletin.gif\">", "bulletin.gif\" />");
 
         QBuffer readBuffer;
         readBuffer.setData(element.toAscii());
@@ -424,7 +425,11 @@ DetailResultInfo parser131500ComAu::getJourneyDetailsData(QString queryUrl)
             }
             item.toStation   = regexp2.cap(1).trimmed();
             item.info        = "Walking " + regexp2.cap(2).trimmed() + " " + regexp2.cap(3).trimmed();
-            result.items.append(item);
+
+            //Don't add WalkTo infos as first item
+            if (result.items.count() > 0) {
+                result.items.append(item);
+            }
         }
     }
     return result;
