@@ -34,6 +34,19 @@ bool parserMvvDe::supportsGps()
     return false;
 }
 
+QStringList parserMvvDe::getTrainRestrictions()
+{
+    QStringList result;
+    /*
+     * Have to check, does not work for me
+    result.append(tr("All"));
+    result.append(tr("All without ICE"));
+    result.append(tr("Only local transport and authority lines"));
+    result.append(tr("Only authority lines without extra charge"));
+    */
+    return result;
+}
+
 QStringList parserMvvDe::getStationsByName(QString stationName)
 {
     QByteArray postData = "sessionID=0&requestID=0&language=en&command=&ptOptionsActive=0&place_origin=&placeState_origin=empty&type_origin=stop&nameState_origin=empty&place_destination=&placeState_destination=empty&type_destination=stop&name_destination=&nameState_destination=empty&place_via=&placeState_via=empty&type_via=stop&name_via=&name_origin=";
@@ -108,7 +121,7 @@ QStringList parserMvvDe::getStationsByGPS(qreal latitude, qreal longitude)
     return result;
 }
 
-ResultInfo parserMvvDe::getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode)
+ResultInfo parserMvvDe::getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode, int trainrestrictions)
 {
     Q_UNUSED(viaStation);
 
@@ -121,6 +134,17 @@ ResultInfo parserMvvDe::getJourneyData(QString destinationStation, QString arriv
         arrivalStation = "M";
     }
 
+    QString trainrestr = "400";
+    if (trainrestrictions == 0) {
+        trainrestr = "400"; //ALL
+    } else if (trainrestrictions == 1) {
+        trainrestr = "401"; //All without ICE
+    } else if (trainrestrictions == 2) {
+        trainrestr = "403"; //Only local transport and authority
+    } else if (trainrestrictions == 3) {
+        trainrestr = "402"; //Only authority without extra fare
+    }
+
     QUrl url("http://efa.mvv-muenchen.de/mobile/XSLT_TRIP_REQUEST2");
 
     QString modeString = "dep";
@@ -145,7 +169,9 @@ ResultInfo parserMvvDe::getJourneyData(QString destinationStation, QString arriv
                        "&itdTimeHour=" +
                        time.toString("hh") +
                        "&itdTimeMinute=" +
-                       time.toString("mm");
+                       time.toString("mm") +
+                       "&lineRestriction=" +
+                       trainrestr;
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
 
