@@ -20,8 +20,11 @@
 
 #include "selectstationdialog.h"
 
-selectStationDialog::selectStationDialog(QMaemo5ValueButton *sender, QGeoPositionInfo *position, parserAbstract *mainBackendParser, QSettings *mainSettings)
+selectStationDialog::selectStationDialog(QValueButton *sender, QGeoPositionInfo *position, parserAbstract *mainBackendParser, QSettings *mainSettings)
 {
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+
     setWindowTitle(tr("City Stationname"));
 
     mainSender     = sender;
@@ -65,44 +68,51 @@ selectStationDialog::selectStationDialog(QMaemo5ValueButton *sender, QGeoPositio
         gpsButton->setEnabled(false);
     }
 
-    QHBoxLayout *hLayout = new QHBoxLayout;
-    QVBoxLayout *vLayout = new QVBoxLayout;
-
-    QWidget *vContainer  = new QWidget;
-
-    searchboxCombo->setFixedWidth(520);
+    gpsButton->setMinimumWidth(210);
+    searchButton->setMinimumWidth(210);
     searchboxCombo->setFixedHeight(72);
-    searchboxText->setFixedWidth(520);
     searchboxText->setFixedHeight(72);
-    gpsButton->setFixedWidth(210);
-    searchButton->setFixedWidth(210);
 
-    vLayout->setMargin(0);
-    vLayout->setStretch(0,0);
-    vLayout->setSpacing(0);
-    vLayout->addWidget(gpsButton);
-    vLayout->addWidget(searchButton);
-    vContainer->setLayout(vLayout);
+    QGridLayout *layout = new QGridLayout();
 
-    if (settings->value("storelastsearch", true).toBool() ==  true)
-    {
-        hLayout->addWidget(searchboxCombo);
-    } else
-    {
-        hLayout->addWidget(searchboxText);
-    }
-    hLayout->addWidget(vContainer);
-
-    setLayout(hLayout);
+    setLayout(layout);
+    orientationChanged();
 }
 
+void selectStationDialog::orientationChanged()
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    QGridLayout *layout = (QGridLayout*)this->layout();
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        layout->addWidget(gpsButton, 0, 1);
+        layout->addWidget(searchButton, 1, 1);
+        if (settings->value("storelastsearch", true).toBool() ==  true)
+        {
+            layout->addWidget(searchboxCombo, 0, 0, 0, 1);
+        } else
+        {
+            layout->addWidget(searchboxText, 0, 0, 0, 1);
+        }
+    } else {
+        layout->addWidget(gpsButton, 1, 0);
+        layout->addWidget(searchButton, 1, 1);
+        if (settings->value("storelastsearch", true).toBool() ==  true)
+        {
+            layout->addWidget(searchboxCombo, 0, 0, 1, 0);
+        } else
+        {
+            layout->addWidget(searchboxText, 0, 0, 1, 0);
+        }
+    }
+}
 
 void selectStationDialog::showSelector(QStringList items)
 {
     //If only one entry found we directly use it.
     if (items.count() == 1)
     {
-        mainSender->setValueText(items[0]);
+        mainSender->setDescription(items[0]);
         this->hide();
         return;
     }
@@ -119,20 +129,19 @@ void selectStationDialog::showSelector(QStringList items)
         stationsModel->appendRow(item);
     }
 
-    QMaemo5ValueButton *tmpButton = new QMaemo5ValueButton(tr("Select a station"));
-    tmpButton->setValueLayout(QMaemo5ValueButton::ValueBesideText);
     QMaemo5ListPickSelector *tmpSelector = new QMaemo5ListPickSelector;
     connect(tmpSelector, SIGNAL(selected(QString)), this, SLOT(stationSelected(QString)));
     tmpSelector->setModel(stationsModel);
-    tmpButton->setPickSelector(tmpSelector);
-    tmpButton->click();
+    QPushButton *tmpButton = new QPushButton(tr("Select a station"));
+    QWidget *w = tmpSelector->widget(tmpButton);
+    w->show();
 }
 
 void selectStationDialog::stationSelected(QString value)
 {
     if (value != "")
     {
-        mainSender->setValueText(value);
+        mainSender->setDescription(value);
         this->hide();
     }
 }
